@@ -1,6 +1,7 @@
-from typing import List
+from typing import List, Optional
 from dataclasses import dataclass
 from kong_config_builder.base import BaseYamlObject
+from kong_config_builder.plugin import Plugin
 
 
 @dataclass
@@ -15,3 +16,4 @@ class Service(BaseYamlObject):
     name: str
     host: str
     routes: List[Route]
+    plugins: Optional[List[Plugin]] = None
